@@ -1,6 +1,6 @@
 # MIT License
 #
-# Copyright (c) 2021 mmb L (Python port)
+# Copyright (c) 2022 mmb L (Python port)
 # Copyright (c) 2021 Wolf Garbe (Original C# implementation)
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -19,16 +19,8 @@
 .. moduleauthor:: Wolf Garbe <wolf.garbe@faroo.com>
 """
 
-__version__ = "6.7.5"
+__version__ = "6.7.7"
 
-import logging
-import os
-
-from . import editdistance, helpers
+from . import editdistance, helpers, logging
 from .symspellpy import SymSpell
 from .verbosity import Verbosity
-
-logging.basicConfig(
-    level=os.environ.get("LOGLEVEL", "WARNING"),
-    format="%(asctime)s %(levelname)s:%(message)s",
-)
