@@ -1,6 +1,6 @@
 # MIT License
 #
-# Copyright (c) 2021 mmb L (Python port)
+# Copyright (c) 2022 mmb L (Python port)
 # Copyright (c) 2021 Wolf Garbe (Original C# implementation)
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -18,6 +18,7 @@
    :synopsis: Module for Symmetric Delete spelling correction algorithm.
 """
 
+import logging
 import math
 import re
 import string
@@ -35,6 +36,9 @@ from symspellpy.pickle_mixin import PickleMixin
 from symspellpy.suggest_item import SuggestItem
 from symspellpy.verbosity import Verbosity
 
+logger = logging.getLogger(__name__)
+WORD_PATTERN = re.compile(r"(([^\W_]|['’])+)")
+
 
 class SymSpell(PickleMixin):
     """Symmetric Delete spelling correction algorithm.
@@ -178,11 +182,10 @@ class SymSpell(PickleMixin):
         if isinstance(corpus, (Path, str)):
             corpus = Path(corpus)
             if not corpus.exists():
+                logger.error(f"Corpus not found at {corpus}.")
                 return False
-            with open(corpus, "r", encoding=encoding) as infile:
-                for line in infile:
-                    for key in self._parse_words(line):
-                        self.create_dictionary_entry(key, 1)
+            for key in self._parse_words(corpus.read_text(encoding=encoding)):
+                self.create_dictionary_entry(key, 1)
         else:
             for line in corpus:
                 for key in self._parse_words(line):
@@ -304,6 +307,7 @@ class SymSpell(PickleMixin):
         """
         corpus = Path(corpus)
         if not corpus.exists():
+            logger.error(f"Bigram dictionary file not found at {corpus}.")
             return False
         with open(corpus, "r", encoding=encoding) as infile:
             return self._load_bigram_dictionary_stream(
@@ -335,6 +339,7 @@ class SymSpell(PickleMixin):
         """
         corpus = Path(corpus)
         if not corpus.exists():
+            logger.error(f"Dictionary file not found at {corpus}.")
             return False
         with open(corpus, "r", encoding=encoding) as infile:
             return self._load_dictionary_stream(
@@ -677,10 +682,10 @@ class SymSpell(PickleMixin):
         for i, _ in enumerate(terms_1):
             if ignore_non_words:
                 if helpers.try_parse_int64(terms_1[i]) is not None:
-                    suggestion_parts.append(SuggestItem(terms_1[i], 0, 0))
+                    suggestion_parts.append(SuggestItem(terms_1[i], 0, self.N))
                     continue
                 if helpers.is_acronym(terms_2[i], ignore_term_with_digits):
-                    suggestion_parts.append(SuggestItem(terms_2[i], 0, 0))
+                    suggestion_parts.append(SuggestItem(terms_2[i], 0, self.N))
                     continue
             suggestions = self.lookup(terms_1[i], Verbosity.TOP, max_edit_distance)
             # combi check, always before split
@@ -1036,9 +1041,8 @@ class SymSpell(PickleMixin):
             return delete_words
         for i in range(current_distance, len(word)):
             delete = word[:i] + word[i + 1 :]
-            if delete in delete_words:
-                continue
-            delete_words.add(delete)
+            if delete not in delete_words:
+                delete_words.add(delete)
             # recursion, if maximum edit distance not yet reached
             if edit_distance < self._max_dictionary_edit_distance:
                 self._edits(delete, edit_distance, delete_words, current_distance=i)
@@ -1134,7 +1138,7 @@ class SymSpell(PickleMixin):
         # excluding "_". Compatible with non-latin characters, does not split
         # words at apostrophes. Uses capturing groups to combine a negated set
         # with a character set.
-        matches = re.findall(r"(([^\W_]|['’])+)", text.lower())
+        matches = WORD_PATTERN.findall(text.lower())
         # The above regex returns ("ghi'jkl", "l") for "ghi'jkl", so we extract
         # the first element
         matches = [match[0] for match in matches]
